Documentation
¶
Index ¶
- type AppLaunchStatus
- type AppReplicationStatus
- type AppStatus
- type AppSummary
- type Connector
- type ConnectorCapability
- type ConnectorStatus
- type InternalError
- type InvalidParameterException
- func (e *InvalidParameterException) Error() string
- func (e *InvalidParameterException) ErrorCode() string
- func (e *InvalidParameterException) ErrorFault() smithy.ErrorFault
- func (e *InvalidParameterException) ErrorMessage() string
- func (e *InvalidParameterException) GetMessage() string
- func (e *InvalidParameterException) HasMessage() bool
- type LaunchDetails
- type LicenseType
- type MissingRequiredParameterException
- func (e *MissingRequiredParameterException) Error() string
- func (e *MissingRequiredParameterException) ErrorCode() string
- func (e *MissingRequiredParameterException) ErrorFault() smithy.ErrorFault
- func (e *MissingRequiredParameterException) ErrorMessage() string
- func (e *MissingRequiredParameterException) GetMessage() string
- func (e *MissingRequiredParameterException) HasMessage() bool
- type NoConnectorsAvailableException
- func (e *NoConnectorsAvailableException) Error() string
- func (e *NoConnectorsAvailableException) ErrorCode() string
- func (e *NoConnectorsAvailableException) ErrorFault() smithy.ErrorFault
- func (e *NoConnectorsAvailableException) ErrorMessage() string
- func (e *NoConnectorsAvailableException) GetMessage() string
- func (e *NoConnectorsAvailableException) HasMessage() bool
- type OperationNotPermittedException
- func (e *OperationNotPermittedException) Error() string
- func (e *OperationNotPermittedException) ErrorCode() string
- func (e *OperationNotPermittedException) ErrorFault() smithy.ErrorFault
- func (e *OperationNotPermittedException) ErrorMessage() string
- func (e *OperationNotPermittedException) GetMessage() string
- func (e *OperationNotPermittedException) HasMessage() bool
- type OutputFormat
- type ReplicationJob
- type ReplicationJobAlreadyExistsException
- func (e *ReplicationJobAlreadyExistsException) Error() string
- func (e *ReplicationJobAlreadyExistsException) ErrorCode() string
- func (e *ReplicationJobAlreadyExistsException) ErrorFault() smithy.ErrorFault
- func (e *ReplicationJobAlreadyExistsException) ErrorMessage() string
- func (e *ReplicationJobAlreadyExistsException) GetMessage() string
- func (e *ReplicationJobAlreadyExistsException) HasMessage() bool
- type ReplicationJobNotFoundException
- func (e *ReplicationJobNotFoundException) Error() string
- func (e *ReplicationJobNotFoundException) ErrorCode() string
- func (e *ReplicationJobNotFoundException) ErrorFault() smithy.ErrorFault
- func (e *ReplicationJobNotFoundException) ErrorMessage() string
- func (e *ReplicationJobNotFoundException) GetMessage() string
- func (e *ReplicationJobNotFoundException) HasMessage() bool
- type ReplicationJobState
- type ReplicationRun
- type ReplicationRunLimitExceededException
- func (e *ReplicationRunLimitExceededException) Error() string
- func (e *ReplicationRunLimitExceededException) ErrorCode() string
- func (e *ReplicationRunLimitExceededException) ErrorFault() smithy.ErrorFault
- func (e *ReplicationRunLimitExceededException) ErrorMessage() string
- func (e *ReplicationRunLimitExceededException) GetMessage() string
- func (e *ReplicationRunLimitExceededException) HasMessage() bool
- type ReplicationRunStageDetails
- type ReplicationRunState
- type ReplicationRunType
- type S3Location
- type Server
- type ServerCannotBeReplicatedException
- func (e *ServerCannotBeReplicatedException) Error() string
- func (e *ServerCannotBeReplicatedException) ErrorCode() string
- func (e *ServerCannotBeReplicatedException) ErrorFault() smithy.ErrorFault
- func (e *ServerCannotBeReplicatedException) ErrorMessage() string
- func (e *ServerCannotBeReplicatedException) GetMessage() string
- func (e *ServerCannotBeReplicatedException) HasMessage() bool
- type ServerCatalogStatus
- type ServerGroup
- type ServerGroupLaunchConfiguration
- type ServerGroupReplicationConfiguration
- type ServerLaunchConfiguration
- type ServerReplicationConfiguration
- type ServerReplicationParameters
- type ServerType
- type Tag
- type TemporarilyUnavailableException
- type UnauthorizedOperationException
- func (e *UnauthorizedOperationException) Error() string
- func (e *UnauthorizedOperationException) ErrorCode() string
- func (e *UnauthorizedOperationException) ErrorFault() smithy.ErrorFault
- func (e *UnauthorizedOperationException) ErrorMessage() string
- func (e *UnauthorizedOperationException) GetMessage() string
- func (e *UnauthorizedOperationException) HasMessage() bool
- type UserData
- type VmManagerType
- type VmServer
- type VmServerAddress
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppLaunchStatus ¶
type AppLaunchStatus string
const ( AppLaunchStatusReadyforconfiguration AppLaunchStatus = "READY_FOR_CONFIGURATION" AppLaunchStatusConfigurationinprogress AppLaunchStatus = "CONFIGURATION_IN_PROGRESS" AppLaunchStatusConfigurationinvalid AppLaunchStatus = "CONFIGURATION_INVALID" AppLaunchStatusReadyforlaunch AppLaunchStatus = "READY_FOR_LAUNCH" AppLaunchStatusValidationinprogress AppLaunchStatus = "VALIDATION_IN_PROGRESS" AppLaunchStatusLaunchpending AppLaunchStatus = "LAUNCH_PENDING" AppLaunchStatusLaunchinprogress AppLaunchStatus = "LAUNCH_IN_PROGRESS" AppLaunchStatusLaunched AppLaunchStatus = "LAUNCHED" AppLaunchStatusDeltalaunchinprogress AppLaunchStatus = "DELTA_LAUNCH_IN_PROGRESS" AppLaunchStatusDeltalaunchfailed AppLaunchStatus = "DELTA_LAUNCH_FAILED" AppLaunchStatusLaunchfailed AppLaunchStatus = "LAUNCH_FAILED" AppLaunchStatusTerminateinprogress AppLaunchStatus = "TERMINATE_IN_PROGRESS" AppLaunchStatusTerminatefailed AppLaunchStatus = "TERMINATE_FAILED" AppLaunchStatusTerminated AppLaunchStatus = "TERMINATED" )
Enum values for AppLaunchStatus
type AppReplicationStatus ¶
type AppReplicationStatus string
const ( AppReplicationStatusReadyforconfiguration AppReplicationStatus = "READY_FOR_CONFIGURATION" AppReplicationStatusConfigurationinprogress AppReplicationStatus = "CONFIGURATION_IN_PROGRESS" AppReplicationStatusConfigurationinvalid AppReplicationStatus = "CONFIGURATION_INVALID" AppReplicationStatusReadyforreplication AppReplicationStatus = "READY_FOR_REPLICATION" AppReplicationStatusValidationinprogress AppReplicationStatus = "VALIDATION_IN_PROGRESS" AppReplicationStatusReplicationpending AppReplicationStatus = "REPLICATION_PENDING" AppReplicationStatusReplicationinprogress AppReplicationStatus = "REPLICATION_IN_PROGRESS" AppReplicationStatusReplicated AppReplicationStatus = "REPLICATED" AppReplicationStatusDeltareplicationinprogress AppReplicationStatus = "DELTA_REPLICATION_IN_PROGRESS" AppReplicationStatusDeltareplicated AppReplicationStatus = "DELTA_REPLICATED" AppReplicationStatusDeltareplicationfailed AppReplicationStatus = "DELTA_REPLICATION_FAILED" AppReplicationStatusReplicationfailed AppReplicationStatus = "REPLICATION_FAILED" AppReplicationStatusReplicationstopping AppReplicationStatus = "REPLICATION_STOPPING" AppReplicationStatusReplicationstopfailed AppReplicationStatus = "REPLICATION_STOP_FAILED" AppReplicationStatusReplicationstopped AppReplicationStatus = "REPLICATION_STOPPED" )
Enum values for AppReplicationStatus
type AppSummary ¶
type AppSummary struct {
// Details about the latest launch of the application.
LaunchDetails *LaunchDetails
// Status of the application.
Status AppStatus
// Launch status of the application.
LaunchStatus AppLaunchStatus
// Description of the application.
Description *string
// Timestamp of the application's creation.
LastModified *time.Time
// Time of creation of this application.
CreationTime *time.Time
// A message related to the status of the application
StatusMessage *string
// Replication status of the application.
ReplicationStatus AppReplicationStatus
// A message related to the launch status of the application.
LaunchStatusMessage *string
// Unique ID of the application.
AppId *string
// Number of server groups present in the application.
TotalServerGroups *int32
// Number of servers present in the application.
TotalServers *int32
// Name of the application.
Name *string
// A message related to the replication status of the application.
ReplicationStatusMessage *string
// Name of the service role in the customer's account used by AWS SMS.
RoleName *string
// Timestamp of the application's most recent successful replication.
LatestReplicationTime *time.Time
}
Information about the application.
type Connector ¶
type Connector struct {
// The name of the VM manager.
VmManagerName *string
// The MAC address of the connector.
MacAddress *string
// The identifier of the connector.
ConnectorId *string
// The identifier of the VM manager.
VmManagerId *string
// The VM management product.
VmManagerType VmManagerType
// The capabilities of the connector.
CapabilityList []ConnectorCapability
// The connector version.
Version *string
// The status of the connector.
Status ConnectorStatus
// The time the connector was associated.
AssociatedOn *time.Time
// The IP address of the connector.
IpAddress *string
}
Represents a connector.
type ConnectorCapability ¶
type ConnectorCapability string
const ( ConnectorCapabilityVsphere ConnectorCapability = "VSPHERE" ConnectorCapabilityScvmm ConnectorCapability = "SCVMM" ConnectorCapabilityHypervmanager ConnectorCapability = "HYPERV-MANAGER" ConnectorCapabilitySnapshotbatching ConnectorCapability = "SNAPSHOT_BATCHING" )
Enum values for ConnectorCapability
type ConnectorStatus ¶
type ConnectorStatus string
const ( ConnectorStatusHealthy ConnectorStatus = "HEALTHY" ConnectorStatusUnhealthy ConnectorStatus = "UNHEALTHY" )
Enum values for ConnectorStatus
type InternalError ¶
type InternalError struct {
Message *string
}
An internal error occurred.
func (*InternalError) Error ¶
func (e *InternalError) Error() string
func (*InternalError) ErrorCode ¶
func (e *InternalError) ErrorCode() string
func (*InternalError) ErrorFault ¶
func (e *InternalError) ErrorFault() smithy.ErrorFault
func (*InternalError) ErrorMessage ¶
func (e *InternalError) ErrorMessage() string
func (*InternalError) GetMessage ¶
func (e *InternalError) GetMessage() string
func (*InternalError) HasMessage ¶
func (e *InternalError) HasMessage() bool
type InvalidParameterException ¶
type InvalidParameterException struct {
Message *string
}
A specified parameter is not valid.
func (*InvalidParameterException) Error ¶
func (e *InvalidParameterException) Error() string
func (*InvalidParameterException) ErrorCode ¶
func (e *InvalidParameterException) ErrorCode() string
func (*InvalidParameterException) ErrorFault ¶
func (e *InvalidParameterException) ErrorFault() smithy.ErrorFault
func (*InvalidParameterException) ErrorMessage ¶
func (e *InvalidParameterException) ErrorMessage() string
func (*InvalidParameterException) GetMessage ¶
func (e *InvalidParameterException) GetMessage() string
func (*InvalidParameterException) HasMessage ¶
func (e *InvalidParameterException) HasMessage() bool
type LaunchDetails ¶
type LaunchDetails struct {
// Name of the latest stack launched for this application.
StackName *string
// Latest time this application was launched successfully.
LatestLaunchTime *time.Time
// Identifier of the latest stack launched for this application.
StackId *string
}
Details about the latest launch of an application.
type LicenseType ¶
type LicenseType string
const ( LicenseTypeAws LicenseType = "AWS" LicenseTypeByol LicenseType = "BYOL" )
Enum values for LicenseType
type MissingRequiredParameterException ¶
type MissingRequiredParameterException struct {
Message *string
}
A required parameter is missing.
func (*MissingRequiredParameterException) Error ¶
func (e *MissingRequiredParameterException) Error() string
func (*MissingRequiredParameterException) ErrorCode ¶
func (e *MissingRequiredParameterException) ErrorCode() string
func (*MissingRequiredParameterException) ErrorFault ¶
func (e *MissingRequiredParameterException) ErrorFault() smithy.ErrorFault
func (*MissingRequiredParameterException) ErrorMessage ¶
func (e *MissingRequiredParameterException) ErrorMessage() string
func (*MissingRequiredParameterException) GetMessage ¶
func (e *MissingRequiredParameterException) GetMessage() string
func (*MissingRequiredParameterException) HasMessage ¶
func (e *MissingRequiredParameterException) HasMessage() bool
type NoConnectorsAvailableException ¶
type NoConnectorsAvailableException struct {
Message *string
}
There are no connectors available.
func (*NoConnectorsAvailableException) Error ¶
func (e *NoConnectorsAvailableException) Error() string
func (*NoConnectorsAvailableException) ErrorCode ¶
func (e *NoConnectorsAvailableException) ErrorCode() string
func (*NoConnectorsAvailableException) ErrorFault ¶
func (e *NoConnectorsAvailableException) ErrorFault() smithy.ErrorFault
func (*NoConnectorsAvailableException) ErrorMessage ¶
func (e *NoConnectorsAvailableException) ErrorMessage() string
func (*NoConnectorsAvailableException) GetMessage ¶
func (e *NoConnectorsAvailableException) GetMessage() string
func (*NoConnectorsAvailableException) HasMessage ¶
func (e *NoConnectorsAvailableException) HasMessage() bool
type OperationNotPermittedException ¶
type OperationNotPermittedException struct {
Message *string
}
This operation is not allowed.
func (*OperationNotPermittedException) Error ¶
func (e *OperationNotPermittedException) Error() string
func (*OperationNotPermittedException) ErrorCode ¶
func (e *OperationNotPermittedException) ErrorCode() string
func (*OperationNotPermittedException) ErrorFault ¶
func (e *OperationNotPermittedException) ErrorFault() smithy.ErrorFault
func (*OperationNotPermittedException) ErrorMessage ¶
func (e *OperationNotPermittedException) ErrorMessage() string
func (*OperationNotPermittedException) GetMessage ¶
func (e *OperationNotPermittedException) GetMessage() string
func (*OperationNotPermittedException) HasMessage ¶
func (e *OperationNotPermittedException) HasMessage() bool
type OutputFormat ¶
type OutputFormat string
const ( OutputFormatJson OutputFormat = "JSON" OutputFormatYaml OutputFormat = "YAML" )
Enum values for OutputFormat
type ReplicationJob ¶
type ReplicationJob struct {
// The description of the replication job.
Description *string
// Information about the replication runs.
ReplicationRunList []*ReplicationRun
// The state of the replication job.
State ReplicationJobState
// The name of the IAM role to be used by the Server Migration Service.
RoleName *string
//
RunOnce *bool
// Information about the VM server.
VmServer *VmServer
// Number of recent AMIs to keep in the customer's account for a replication job.
// By default the value is set to zero, meaning that all AMIs are kept.
NumberOfRecentAmisToKeep *int32
// The identifier of the server.
ServerId *string
// The time between consecutive replication runs, in hours.
Frequency *int32
// The identifier of the replication job.
ReplicationJobId *string
// The description of the current status of the replication job.
StatusMessage *string
// Whether the replication job should produce encrypted AMIs or not. See also
// KmsKeyId below.
Encrypted *bool
// KMS key ID for replication jobs that produce encrypted AMIs. Can be any of the
// following:
//
// * KMS key ID
//
// * KMS key alias
//
// * ARN referring to KMS
// key ID
//
// * ARN referring to KMS key alias
//
// If encrypted is true but a KMS key
// id is not specified, the customer's default KMS key for EBS is used.
KmsKeyId *string
// The license type to be used for the AMI created by a successful replication run.
LicenseType LicenseType
// The type of server.
ServerType ServerType
// The seed replication time.
SeedReplicationTime *time.Time
// The start time of the next replication run.
NextReplicationRunStartTime *time.Time
// The ID of the latest Amazon Machine Image (AMI).
LatestAmiId *string
}
Represents a replication job.
type ReplicationJobAlreadyExistsException ¶
type ReplicationJobAlreadyExistsException struct {
Message *string
}
The specified replication job already exists.
func (*ReplicationJobAlreadyExistsException) Error ¶
func (e *ReplicationJobAlreadyExistsException) Error() string
func (*ReplicationJobAlreadyExistsException) ErrorCode ¶
func (e *ReplicationJobAlreadyExistsException) ErrorCode() string
func (*ReplicationJobAlreadyExistsException) ErrorFault ¶
func (e *ReplicationJobAlreadyExistsException) ErrorFault() smithy.ErrorFault
func (*ReplicationJobAlreadyExistsException) ErrorMessage ¶
func (e *ReplicationJobAlreadyExistsException) ErrorMessage() string
func (*ReplicationJobAlreadyExistsException) GetMessage ¶
func (e *ReplicationJobAlreadyExistsException) GetMessage() string
func (*ReplicationJobAlreadyExistsException) HasMessage ¶
func (e *ReplicationJobAlreadyExistsException) HasMessage() bool
type ReplicationJobNotFoundException ¶
type ReplicationJobNotFoundException struct {
Message *string
}
The specified replication job does not exist.
func (*ReplicationJobNotFoundException) Error ¶
func (e *ReplicationJobNotFoundException) Error() string
func (*ReplicationJobNotFoundException) ErrorCode ¶
func (e *ReplicationJobNotFoundException) ErrorCode() string
func (*ReplicationJobNotFoundException) ErrorFault ¶
func (e *ReplicationJobNotFoundException) ErrorFault() smithy.ErrorFault
func (*ReplicationJobNotFoundException) ErrorMessage ¶
func (e *ReplicationJobNotFoundException) ErrorMessage() string
func (*ReplicationJobNotFoundException) GetMessage ¶
func (e *ReplicationJobNotFoundException) GetMessage() string
func (*ReplicationJobNotFoundException) HasMessage ¶
func (e *ReplicationJobNotFoundException) HasMessage() bool
type ReplicationJobState ¶
type ReplicationJobState string
const ( ReplicationJobStatePending ReplicationJobState = "PENDING" ReplicationJobStateActive ReplicationJobState = "ACTIVE" ReplicationJobStateFailed ReplicationJobState = "FAILED" ReplicationJobStateDeleting ReplicationJobState = "DELETING" ReplicationJobStateDeleted ReplicationJobState = "DELETED" ReplicationJobStateCompleted ReplicationJobState = "COMPLETED" ReplicationJobStatePausedonfailure ReplicationJobState = "PAUSED_ON_FAILURE" ReplicationJobStateFailing ReplicationJobState = "FAILING" )
Enum values for ReplicationJobState
type ReplicationRun ¶
type ReplicationRun struct {
// The completion time of the last replication run.
CompletedTime *time.Time
// KMS key ID for replication jobs that produce encrypted AMIs. Can be any of the
// following:
//
// * KMS key ID
//
// * KMS key alias
//
// * ARN referring to KMS
// key ID
//
// * ARN referring to KMS key alias
//
// If encrypted is true but a KMS key
// id is not specified, the customer's default KMS key for EBS is used.
KmsKeyId *string
// The state of the replication run.
State ReplicationRunState
// The start time of the next replication run.
ScheduledStartTime *time.Time
// Details of the current stage of the replication run.
StageDetails *ReplicationRunStageDetails
// Whether the replication run should produce encrypted AMI or not. See also
// KmsKeyId below.
Encrypted *bool
// The identifier of the Amazon Machine Image (AMI) from the replication run.
AmiId *string
// The description of the replication run.
Description *string
// The type of replication run.
Type ReplicationRunType
// The identifier of the replication run.
ReplicationRunId *string
// The description of the current status of the replication job.
StatusMessage *string
}
Represents a replication run.
type ReplicationRunLimitExceededException ¶
type ReplicationRunLimitExceededException struct {
Message *string
}
You have exceeded the number of on-demand replication runs you can request in a 24-hour period.
func (*ReplicationRunLimitExceededException) Error ¶
func (e *ReplicationRunLimitExceededException) Error() string
func (*ReplicationRunLimitExceededException) ErrorCode ¶
func (e *ReplicationRunLimitExceededException) ErrorCode() string
func (*ReplicationRunLimitExceededException) ErrorFault ¶
func (e *ReplicationRunLimitExceededException) ErrorFault() smithy.ErrorFault
func (*ReplicationRunLimitExceededException) ErrorMessage ¶
func (e *ReplicationRunLimitExceededException) ErrorMessage() string
func (*ReplicationRunLimitExceededException) GetMessage ¶
func (e *ReplicationRunLimitExceededException) GetMessage() string
func (*ReplicationRunLimitExceededException) HasMessage ¶
func (e *ReplicationRunLimitExceededException) HasMessage() bool
type ReplicationRunStageDetails ¶
type ReplicationRunStageDetails struct {
// String describing the progress of the current stage of a replication run.
StageProgress *string
// String describing the current stage of a replication run.
Stage *string
}
Details of the current stage of a replication run.
type ReplicationRunState ¶
type ReplicationRunState string
const ( ReplicationRunStatePending ReplicationRunState = "PENDING" ReplicationRunStateMissed ReplicationRunState = "MISSED" ReplicationRunStateActive ReplicationRunState = "ACTIVE" ReplicationRunStateFailed ReplicationRunState = "FAILED" ReplicationRunStateCompleted ReplicationRunState = "COMPLETED" ReplicationRunStateDeleting ReplicationRunState = "DELETING" ReplicationRunStateDeleted ReplicationRunState = "DELETED" )
Enum values for ReplicationRunState
type ReplicationRunType ¶
type ReplicationRunType string
const ( ReplicationRunTypeOndemand ReplicationRunType = "ON_DEMAND" ReplicationRunTypeAutomatic ReplicationRunType = "AUTOMATIC" )
Enum values for ReplicationRunType
type S3Location ¶
type S3Location struct {
// Amazon S3 bucket key.
Key *string
// Amazon S3 bucket name.
Bucket *string
}
Location of the Amazon S3 object in the customer's account.
type Server ¶
type Server struct {
// Information about the VM server.
VmServer *VmServer
// The type of server.
ServerType ServerType
// Indicates whether the replication job is deleted or failed.
ReplicationJobTerminated *bool
// The identifier of the replication job.
ReplicationJobId *string
// The identifier of the server.
ServerId *string
}
Represents a server.
type ServerCannotBeReplicatedException ¶
type ServerCannotBeReplicatedException struct {
Message *string
}
The specified server cannot be replicated.
func (*ServerCannotBeReplicatedException) Error ¶
func (e *ServerCannotBeReplicatedException) Error() string
func (*ServerCannotBeReplicatedException) ErrorCode ¶
func (e *ServerCannotBeReplicatedException) ErrorCode() string
func (*ServerCannotBeReplicatedException) ErrorFault ¶
func (e *ServerCannotBeReplicatedException) ErrorFault() smithy.ErrorFault
func (*ServerCannotBeReplicatedException) ErrorMessage ¶
func (e *ServerCannotBeReplicatedException) ErrorMessage() string
func (*ServerCannotBeReplicatedException) GetMessage ¶
func (e *ServerCannotBeReplicatedException) GetMessage() string
func (*ServerCannotBeReplicatedException) HasMessage ¶
func (e *ServerCannotBeReplicatedException) HasMessage() bool
type ServerCatalogStatus ¶
type ServerCatalogStatus string
const ( ServerCatalogStatusNotimported ServerCatalogStatus = "NOT_IMPORTED" ServerCatalogStatusImporting ServerCatalogStatus = "IMPORTING" ServerCatalogStatusAvailable ServerCatalogStatus = "AVAILABLE" ServerCatalogStatusDeleted ServerCatalogStatus = "DELETED" ServerCatalogStatusExpired ServerCatalogStatus = "EXPIRED" )
Enum values for ServerCatalogStatus
type ServerGroup ¶
type ServerGroup struct {
// Identifier of a server group.
ServerGroupId *string
// Name of a server group.
Name *string
// List of servers belonging to a server group.
ServerList []*Server
}
A logical grouping of servers.
type ServerGroupLaunchConfiguration ¶
type ServerGroupLaunchConfiguration struct {
// Launch order of servers in the server group.
LaunchOrder *int32
// Launch configuration for servers in the server group.
ServerLaunchConfigurations []*ServerLaunchConfiguration
// Identifier of the server group the launch configuration is associated with.
ServerGroupId *string
}
Launch configuration for a server group.
type ServerGroupReplicationConfiguration ¶
type ServerGroupReplicationConfiguration struct {
// Replication configuration for servers in the server group.
ServerReplicationConfigurations []*ServerReplicationConfiguration
// Identifier of the server group this replication configuration is associated
// with.
ServerGroupId *string
}
Replication configuration for a server group.
type ServerLaunchConfiguration ¶
type ServerLaunchConfiguration struct {
// Identifier of the security group that applies to the launched server.
SecurityGroup *string
// If true, a publicly accessible IP address is created when launching the server.
AssociatePublicIpAddress *bool
// Identifier of the VPC the server should be launched into.
Vpc *string
// Logical ID of the server in the Amazon CloudFormation template.
LogicalId *string
// Instance type to be used for launching the server.
InstanceType *string
// Identifier of the subnet the server should be launched into.
Subnet *string
// Identifier of the server the launch configuration is associated with.
Server *Server
// Name of the EC2 SSH Key to be used for connecting to the launched server.
Ec2KeyName *string
// Location of the user-data script to be executed when launching the server.
UserData *UserData
}
Launch configuration for a server.
type ServerReplicationConfiguration ¶
type ServerReplicationConfiguration struct {
// Identifier of the server this replication configuration is associated with.
Server *Server
// Parameters for replicating the server.
ServerReplicationParameters *ServerReplicationParameters
}
Replication configuration of a server.
type ServerReplicationParameters ¶
type ServerReplicationParameters struct {
// Frequency of creating replication jobs for the server.
Frequency *int32
// KMS key ID for replication jobs that produce encrypted AMIs. Can be any of the
// following:
//
// * KMS key ID
//
// * KMS key alias
//
// * ARN referring to KMS
// key ID
//
// * ARN referring to KMS key alias
//
// If encrypted is true but a KMS key
// id is not specified, the customer's default KMS key for EBS is used.
KmsKeyId *string
//
RunOnce *bool
// Number of recent AMIs to keep when creating a replication job for this server.
NumberOfRecentAmisToKeep *int32
// License type for creating a replication job for the server.
LicenseType LicenseType
// When true, the replication job produces encrypted AMIs. See also KmsKeyId below.
Encrypted *bool
// Seed time for creating a replication job for the server.
SeedTime *time.Time
}
Replication parameters for replicating a server.
type ServerType ¶
type ServerType string
const (
ServerTypeVirtualmachine ServerType = "VIRTUAL_MACHINE"
)
Enum values for ServerType
type TemporarilyUnavailableException ¶
type TemporarilyUnavailableException struct {
}
The service is temporarily unavailable.
func (*TemporarilyUnavailableException) Error ¶
func (e *TemporarilyUnavailableException) Error() string
func (*TemporarilyUnavailableException) ErrorCode ¶
func (e *TemporarilyUnavailableException) ErrorCode() string
func (*TemporarilyUnavailableException) ErrorFault ¶
func (e *TemporarilyUnavailableException) ErrorFault() smithy.ErrorFault
func (*TemporarilyUnavailableException) ErrorMessage ¶
func (e *TemporarilyUnavailableException) ErrorMessage() string
type UnauthorizedOperationException ¶
type UnauthorizedOperationException struct {
}
You lack permissions needed to perform this operation. Check your IAM policies, and ensure that you are using the correct access keys.
func (*UnauthorizedOperationException) Error ¶
func (e *UnauthorizedOperationException) Error() string
func (*UnauthorizedOperationException) ErrorCode ¶
func (e *UnauthorizedOperationException) ErrorCode() string
func (*UnauthorizedOperationException) ErrorFault ¶
func (e *UnauthorizedOperationException) ErrorFault() smithy.ErrorFault
func (*UnauthorizedOperationException) ErrorMessage ¶
func (e *UnauthorizedOperationException) ErrorMessage() string
func (*UnauthorizedOperationException) GetMessage ¶
func (e *UnauthorizedOperationException) GetMessage() string
func (*UnauthorizedOperationException) HasMessage ¶
func (e *UnauthorizedOperationException) HasMessage() bool
type UserData ¶
type UserData struct {
// Amazon S3 location of the user-data script.
S3Location *S3Location
}
A script that runs on first launch of an Amazon EC2 instance. Used for configuring the server during launch.
type VmManagerType ¶
type VmManagerType string
const ( VmManagerTypeVsphere VmManagerType = "VSPHERE" VmManagerTypeScvmm VmManagerType = "SCVMM" VmManagerTypeHypervmanager VmManagerType = "HYPERV-MANAGER" )
Enum values for VmManagerType
type VmServer ¶
type VmServer struct {
// The VM folder path in the vCenter Server virtual machine inventory tree.
VmPath *string
// The name of the VM manager.
VmManagerName *string
// The name of the VM.
VmName *string
// Information about the VM server location.
VmServerAddress *VmServerAddress
// The type of VM management product.
VmManagerType VmManagerType
}
Represents a VM server.
type VmServerAddress ¶
type VmServerAddress struct {
// The identifier of the VM manager.
VmManagerId *string
// The identifier of the VM.
VmId *string
}
Represents a VM server location.