Documentation
¶
Index ¶
- type AccessDeniedException
- func (e *AccessDeniedException) Error() string
- func (e *AccessDeniedException) ErrorCode() string
- func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault
- func (e *AccessDeniedException) ErrorMessage() string
- func (e *AccessDeniedException) GetMessage() string
- func (e *AccessDeniedException) HasMessage() bool
- type AccessPropertyValue
- type AccountModification
- type ClientProperties
- type ClientPropertiesResult
- type Compute
- type ComputeType
- type ConnectionState
- type DedicatedTenancyModificationStateEnum
- type DedicatedTenancySupportEnum
- type DedicatedTenancySupportResultEnum
- type DefaultWorkspaceCreationProperties
- type FailedCreateWorkspaceRequest
- type FailedWorkspaceChangeRequest
- type ImagePermission
- type ImageType
- type InvalidParameterValuesException
- func (e *InvalidParameterValuesException) Error() string
- func (e *InvalidParameterValuesException) ErrorCode() string
- func (e *InvalidParameterValuesException) ErrorFault() smithy.ErrorFault
- func (e *InvalidParameterValuesException) ErrorMessage() string
- func (e *InvalidParameterValuesException) GetMessage() string
- func (e *InvalidParameterValuesException) HasMessage() bool
- type InvalidResourceStateException
- func (e *InvalidResourceStateException) Error() string
- func (e *InvalidResourceStateException) ErrorCode() string
- func (e *InvalidResourceStateException) ErrorFault() smithy.ErrorFault
- func (e *InvalidResourceStateException) ErrorMessage() string
- func (e *InvalidResourceStateException) GetMessage() string
- func (e *InvalidResourceStateException) HasMessage() bool
- type IpRuleItem
- type ModificationResourceEnum
- type ModificationState
- type ModificationStateEnum
- type OperatingSystem
- type OperatingSystemType
- type OperationInProgressException
- func (e *OperationInProgressException) Error() string
- func (e *OperationInProgressException) ErrorCode() string
- func (e *OperationInProgressException) ErrorFault() smithy.ErrorFault
- func (e *OperationInProgressException) ErrorMessage() string
- func (e *OperationInProgressException) GetMessage() string
- func (e *OperationInProgressException) HasMessage() bool
- type OperationNotSupportedException
- func (e *OperationNotSupportedException) Error() string
- func (e *OperationNotSupportedException) ErrorCode() string
- func (e *OperationNotSupportedException) ErrorFault() smithy.ErrorFault
- func (e *OperationNotSupportedException) ErrorMessage() string
- func (e *OperationNotSupportedException) GetMessage() string
- func (e *OperationNotSupportedException) HasMessage() bool
- type RebootRequest
- type RebuildRequest
- type ReconnectEnum
- type ResourceAlreadyExistsException
- func (e *ResourceAlreadyExistsException) Error() string
- func (e *ResourceAlreadyExistsException) ErrorCode() string
- func (e *ResourceAlreadyExistsException) ErrorFault() smithy.ErrorFault
- func (e *ResourceAlreadyExistsException) ErrorMessage() string
- func (e *ResourceAlreadyExistsException) GetMessage() string
- func (e *ResourceAlreadyExistsException) HasMessage() bool
- type ResourceAssociatedException
- func (e *ResourceAssociatedException) Error() string
- func (e *ResourceAssociatedException) ErrorCode() string
- func (e *ResourceAssociatedException) ErrorFault() smithy.ErrorFault
- func (e *ResourceAssociatedException) ErrorMessage() string
- func (e *ResourceAssociatedException) GetMessage() string
- func (e *ResourceAssociatedException) HasMessage() bool
- type ResourceCreationFailedException
- func (e *ResourceCreationFailedException) Error() string
- func (e *ResourceCreationFailedException) ErrorCode() string
- func (e *ResourceCreationFailedException) ErrorFault() smithy.ErrorFault
- func (e *ResourceCreationFailedException) ErrorMessage() string
- func (e *ResourceCreationFailedException) GetMessage() string
- func (e *ResourceCreationFailedException) HasMessage() bool
- type ResourceLimitExceededException
- func (e *ResourceLimitExceededException) Error() string
- func (e *ResourceLimitExceededException) ErrorCode() string
- func (e *ResourceLimitExceededException) ErrorFault() smithy.ErrorFault
- func (e *ResourceLimitExceededException) ErrorMessage() string
- func (e *ResourceLimitExceededException) GetMessage() string
- func (e *ResourceLimitExceededException) HasMessage() bool
- type ResourceNotFoundException
- func (e *ResourceNotFoundException) Error() string
- func (e *ResourceNotFoundException) ErrorCode() string
- func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
- func (e *ResourceNotFoundException) ErrorMessage() string
- func (e *ResourceNotFoundException) GetMessage() string
- func (e *ResourceNotFoundException) GetResourceId() string
- func (e *ResourceNotFoundException) HasMessage() bool
- func (e *ResourceNotFoundException) HasResourceId() bool
- type ResourceUnavailableException
- func (e *ResourceUnavailableException) Error() string
- func (e *ResourceUnavailableException) ErrorCode() string
- func (e *ResourceUnavailableException) ErrorFault() smithy.ErrorFault
- func (e *ResourceUnavailableException) ErrorMessage() string
- func (e *ResourceUnavailableException) GetMessage() string
- func (e *ResourceUnavailableException) GetResourceId() string
- func (e *ResourceUnavailableException) HasMessage() bool
- func (e *ResourceUnavailableException) HasResourceId() bool
- type RootStorage
- type RunningMode
- type SelfservicePermissions
- type Snapshot
- type StartRequest
- type StopRequest
- type Tag
- type TargetWorkspaceState
- type Tenancy
- type TerminateRequest
- type UnsupportedNetworkConfigurationException
- func (e *UnsupportedNetworkConfigurationException) Error() string
- func (e *UnsupportedNetworkConfigurationException) ErrorCode() string
- func (e *UnsupportedNetworkConfigurationException) ErrorFault() smithy.ErrorFault
- func (e *UnsupportedNetworkConfigurationException) ErrorMessage() string
- func (e *UnsupportedNetworkConfigurationException) GetMessage() string
- func (e *UnsupportedNetworkConfigurationException) HasMessage() bool
- type UnsupportedWorkspaceConfigurationException
- func (e *UnsupportedWorkspaceConfigurationException) Error() string
- func (e *UnsupportedWorkspaceConfigurationException) ErrorCode() string
- func (e *UnsupportedWorkspaceConfigurationException) ErrorFault() smithy.ErrorFault
- func (e *UnsupportedWorkspaceConfigurationException) ErrorMessage() string
- func (e *UnsupportedWorkspaceConfigurationException) GetMessage() string
- func (e *UnsupportedWorkspaceConfigurationException) HasMessage() bool
- type UserStorage
- type Workspace
- type WorkspaceAccessProperties
- type WorkspaceBundle
- type WorkspaceConnectionStatus
- type WorkspaceCreationProperties
- type WorkspaceDirectory
- type WorkspaceDirectoryState
- type WorkspaceDirectoryType
- type WorkspaceImage
- type WorkspaceImageIngestionProcess
- type WorkspaceImageRequiredTenancy
- type WorkspaceImageState
- type WorkspaceProperties
- type WorkspaceRequest
- type WorkspaceState
- type WorkspacesDefaultRoleNotFoundException
- func (e *WorkspacesDefaultRoleNotFoundException) Error() string
- func (e *WorkspacesDefaultRoleNotFoundException) ErrorCode() string
- func (e *WorkspacesDefaultRoleNotFoundException) ErrorFault() smithy.ErrorFault
- func (e *WorkspacesDefaultRoleNotFoundException) ErrorMessage() string
- func (e *WorkspacesDefaultRoleNotFoundException) GetMessage() string
- func (e *WorkspacesDefaultRoleNotFoundException) HasMessage() bool
- type WorkspacesIpGroup
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessDeniedException ¶
type AccessDeniedException struct {
Message *string
}
The user is not authorized to access a resource.
func (*AccessDeniedException) Error ¶
func (e *AccessDeniedException) Error() string
func (*AccessDeniedException) ErrorCode ¶
func (e *AccessDeniedException) ErrorCode() string
func (*AccessDeniedException) ErrorFault ¶
func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault
func (*AccessDeniedException) ErrorMessage ¶
func (e *AccessDeniedException) ErrorMessage() string
func (*AccessDeniedException) GetMessage ¶
func (e *AccessDeniedException) GetMessage() string
func (*AccessDeniedException) HasMessage ¶
func (e *AccessDeniedException) HasMessage() bool
type AccessPropertyValue ¶
type AccessPropertyValue string
const ( AccessPropertyValueAllow AccessPropertyValue = "ALLOW" AccessPropertyValueDeny AccessPropertyValue = "DENY" )
Enum values for AccessPropertyValue
type AccountModification ¶
type AccountModification struct {
// The text of the error message that is returned if the configuration of BYOL
// cannot be modified.
ErrorMessage *string
// The state of the modification to the configuration of BYOL.
ModificationState DedicatedTenancyModificationStateEnum
// The IP address range, specified as an IPv4 CIDR block, for the management
// network interface used for the account.
DedicatedTenancyManagementCidrRange *string
// The error code that is returned if the configuration of BYOL cannot be modified.
ErrorCode *string
// The timestamp when the modification of the BYOL configuration was started.
StartTime *time.Time
// The status of BYOL (whether BYOL is being enabled or disabled).
DedicatedTenancySupport DedicatedTenancySupportResultEnum
}
Describes a modification to the configuration of Bring Your Own License (BYOL) for the specified account.
type ClientProperties ¶
type ClientProperties struct {
// Specifies whether users can cache their credentials on the Amazon WorkSpaces
// client. When enabled, users can choose to reconnect to their WorkSpaces without
// re-entering their credentials.
ReconnectEnabled ReconnectEnum
}
Describes an Amazon WorkSpaces client.
type ClientPropertiesResult ¶
type ClientPropertiesResult struct {
// The resource identifier, in the form of a directory ID.
ResourceId *string
// Information about the Amazon WorkSpaces client.
ClientProperties *ClientProperties
}
Information about the Amazon WorkSpaces client.
type ComputeType ¶
type ComputeType struct {
// The compute type.
Name Compute
}
Describes the compute type.
type ConnectionState ¶
type ConnectionState string
const ( ConnectionStateConnected ConnectionState = "CONNECTED" ConnectionStateDisconnected ConnectionState = "DISCONNECTED" ConnectionStateUnknown ConnectionState = "UNKNOWN" )
Enum values for ConnectionState
type DedicatedTenancyModificationStateEnum ¶
type DedicatedTenancyModificationStateEnum string
const ( DedicatedTenancyModificationStateEnumPending DedicatedTenancyModificationStateEnum = "PENDING" DedicatedTenancyModificationStateEnumCompleted DedicatedTenancyModificationStateEnum = "COMPLETED" DedicatedTenancyModificationStateEnumFailed DedicatedTenancyModificationStateEnum = "FAILED" )
Enum values for DedicatedTenancyModificationStateEnum
type DedicatedTenancySupportEnum ¶
type DedicatedTenancySupportEnum string
const (
DedicatedTenancySupportEnumEnabled DedicatedTenancySupportEnum = "ENABLED"
)
Enum values for DedicatedTenancySupportEnum
type DedicatedTenancySupportResultEnum ¶
type DedicatedTenancySupportResultEnum string
const ( DedicatedTenancySupportResultEnumEnabled DedicatedTenancySupportResultEnum = "ENABLED" DedicatedTenancySupportResultEnumDisabled DedicatedTenancySupportResultEnum = "DISABLED" )
Enum values for DedicatedTenancySupportResultEnum
type DefaultWorkspaceCreationProperties ¶
type DefaultWorkspaceCreationProperties struct {
// The identifier of the default security group to apply to WorkSpaces when they
// are created. For more information, see Security Groups for Your WorkSpaces
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/amazon-workspaces-security-groups.html).
CustomSecurityGroupId *string
// Specifies whether to automatically assign an Elastic public IP address to
// WorkSpaces in this directory by default. If enabled, the Elastic public IP
// address allows outbound internet access from your WorkSpaces when you’re using
// an internet gateway in the Amazon VPC in which your WorkSpaces are located. If
// you're using a Network Address Translation (NAT) gateway for outbound internet
// access from your VPC, or if your WorkSpaces are in public subnets and you
// manually assign them Elastic IP addresses, you should disable this setting. This
// setting applies to new WorkSpaces that you launch or to existing WorkSpaces that
// you rebuild. For more information, see Configure a VPC for Amazon WorkSpaces
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/amazon-workspaces-vpc.html).
EnableInternetAccess *bool
// Specifies whether the directory is enabled for Amazon WorkDocs.
EnableWorkDocs *bool
// The organizational unit (OU) in the directory for the WorkSpace machine
// accounts.
DefaultOu *string
// Specifies whether maintenance mode is enabled for WorkSpaces. For more
// information, see WorkSpace Maintenance
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/workspace-maintenance.html).
EnableMaintenanceMode *bool
// Specifies whether WorkSpace users are local administrators on their WorkSpaces.
UserEnabledAsLocalAdministrator *bool
}
Describes the default values that are used to create WorkSpaces. For more information, see Update Directory Details for Your WorkSpaces (https://docs.aws.amazon.com/workspaces/latest/adminguide/update-directory-details.html).
type FailedCreateWorkspaceRequest ¶
type FailedCreateWorkspaceRequest struct {
// Information about the WorkSpace.
WorkspaceRequest *WorkspaceRequest
// The text of the error message that is returned if the WorkSpace cannot be
// created.
ErrorMessage *string
// The error code that is returned if the WorkSpace cannot be created.
ErrorCode *string
}
Describes a WorkSpace that cannot be created.
type FailedWorkspaceChangeRequest ¶
type FailedWorkspaceChangeRequest struct {
// The text of the error message that is returned if the WorkSpace cannot be
// rebooted.
ErrorMessage *string
// The error code that is returned if the WorkSpace cannot be rebooted.
ErrorCode *string
// The identifier of the WorkSpace.
WorkspaceId *string
}
Describes a WorkSpace that could not be rebooted. (RebootWorkspaces ()), rebuilt (RebuildWorkspaces ()), restored (RestoreWorkspace ()), terminated (TerminateWorkspaces ()), started (StartWorkspaces ()), or stopped (StopWorkspaces ()).
type ImagePermission ¶
type ImagePermission struct {
SharedAccountId *string
}
Describes the AWS accounts that have been granted permission to use a shared image.
type ImageType ¶
type ImageType string
const ( ImageTypeOwned ImageType = "OWNED" )
Enum values for ImageType
type InvalidParameterValuesException ¶
type InvalidParameterValuesException struct {
Message *string
}
One or more parameter values are not valid.
func (*InvalidParameterValuesException) Error ¶
func (e *InvalidParameterValuesException) Error() string
func (*InvalidParameterValuesException) ErrorCode ¶
func (e *InvalidParameterValuesException) ErrorCode() string
func (*InvalidParameterValuesException) ErrorFault ¶
func (e *InvalidParameterValuesException) ErrorFault() smithy.ErrorFault
func (*InvalidParameterValuesException) ErrorMessage ¶
func (e *InvalidParameterValuesException) ErrorMessage() string
func (*InvalidParameterValuesException) GetMessage ¶
func (e *InvalidParameterValuesException) GetMessage() string
func (*InvalidParameterValuesException) HasMessage ¶
func (e *InvalidParameterValuesException) HasMessage() bool
type InvalidResourceStateException ¶
type InvalidResourceStateException struct {
Message *string
}
The state of the resource is not valid for this operation.
func (*InvalidResourceStateException) Error ¶
func (e *InvalidResourceStateException) Error() string
func (*InvalidResourceStateException) ErrorCode ¶
func (e *InvalidResourceStateException) ErrorCode() string
func (*InvalidResourceStateException) ErrorFault ¶
func (e *InvalidResourceStateException) ErrorFault() smithy.ErrorFault
func (*InvalidResourceStateException) ErrorMessage ¶
func (e *InvalidResourceStateException) ErrorMessage() string
func (*InvalidResourceStateException) GetMessage ¶
func (e *InvalidResourceStateException) GetMessage() string
func (*InvalidResourceStateException) HasMessage ¶
func (e *InvalidResourceStateException) HasMessage() bool
type IpRuleItem ¶
type IpRuleItem struct {
// The IP address range, in CIDR notation.
IpRule *string
// The description.
RuleDesc *string
}
Describes a rule for an IP access control group.
type ModificationResourceEnum ¶
type ModificationResourceEnum string
const ( ModificationResourceEnumRoot_volume ModificationResourceEnum = "ROOT_VOLUME" ModificationResourceEnumUser_volume ModificationResourceEnum = "USER_VOLUME" ModificationResourceEnumCompute_type ModificationResourceEnum = "COMPUTE_TYPE" )
Enum values for ModificationResourceEnum
type ModificationState ¶
type ModificationState struct {
// The resource.
Resource ModificationResourceEnum
// The modification state.
State ModificationStateEnum
}
Describes a WorkSpace modification.
type ModificationStateEnum ¶
type ModificationStateEnum string
const ( ModificationStateEnumUpdate_initiated ModificationStateEnum = "UPDATE_INITIATED" ModificationStateEnumUpdate_in_progress ModificationStateEnum = "UPDATE_IN_PROGRESS" )
Enum values for ModificationStateEnum
type OperatingSystem ¶
type OperatingSystem struct {
// The operating system.
Type OperatingSystemType
}
The operating system that the image is running.
type OperatingSystemType ¶
type OperatingSystemType string
const ( OperatingSystemTypeWindows OperatingSystemType = "WINDOWS" OperatingSystemTypeLinux OperatingSystemType = "LINUX" )
Enum values for OperatingSystemType
type OperationInProgressException ¶
type OperationInProgressException struct {
Message *string
}
The properties of this WorkSpace are currently being modified. Try again in a moment.
func (*OperationInProgressException) Error ¶
func (e *OperationInProgressException) Error() string
func (*OperationInProgressException) ErrorCode ¶
func (e *OperationInProgressException) ErrorCode() string
func (*OperationInProgressException) ErrorFault ¶
func (e *OperationInProgressException) ErrorFault() smithy.ErrorFault
func (*OperationInProgressException) ErrorMessage ¶
func (e *OperationInProgressException) ErrorMessage() string
func (*OperationInProgressException) GetMessage ¶
func (e *OperationInProgressException) GetMessage() string
func (*OperationInProgressException) HasMessage ¶
func (e *OperationInProgressException) HasMessage() bool
type OperationNotSupportedException ¶
type OperationNotSupportedException struct {
Message *string
}
This operation is not supported.
func (*OperationNotSupportedException) Error ¶
func (e *OperationNotSupportedException) Error() string
func (*OperationNotSupportedException) ErrorCode ¶
func (e *OperationNotSupportedException) ErrorCode() string
func (*OperationNotSupportedException) ErrorFault ¶
func (e *OperationNotSupportedException) ErrorFault() smithy.ErrorFault
func (*OperationNotSupportedException) ErrorMessage ¶
func (e *OperationNotSupportedException) ErrorMessage() string
func (*OperationNotSupportedException) GetMessage ¶
func (e *OperationNotSupportedException) GetMessage() string
func (*OperationNotSupportedException) HasMessage ¶
func (e *OperationNotSupportedException) HasMessage() bool
type RebootRequest ¶
type RebootRequest struct {
// The identifier of the WorkSpace.
WorkspaceId *string
}
Describes the information used to reboot a WorkSpace.
type RebuildRequest ¶
type RebuildRequest struct {
// The identifier of the WorkSpace.
WorkspaceId *string
}
Describes the information used to rebuild a WorkSpace.
type ReconnectEnum ¶
type ReconnectEnum string
const ( ReconnectEnumEnabled ReconnectEnum = "ENABLED" ReconnectEnumDisabled ReconnectEnum = "DISABLED" )
Enum values for ReconnectEnum
type ResourceAlreadyExistsException ¶
type ResourceAlreadyExistsException struct {
Message *string
}
The specified resource already exists.
func (*ResourceAlreadyExistsException) Error ¶
func (e *ResourceAlreadyExistsException) Error() string
func (*ResourceAlreadyExistsException) ErrorCode ¶
func (e *ResourceAlreadyExistsException) ErrorCode() string
func (*ResourceAlreadyExistsException) ErrorFault ¶
func (e *ResourceAlreadyExistsException) ErrorFault() smithy.ErrorFault
func (*ResourceAlreadyExistsException) ErrorMessage ¶
func (e *ResourceAlreadyExistsException) ErrorMessage() string
func (*ResourceAlreadyExistsException) GetMessage ¶
func (e *ResourceAlreadyExistsException) GetMessage() string
func (*ResourceAlreadyExistsException) HasMessage ¶
func (e *ResourceAlreadyExistsException) HasMessage() bool
type ResourceAssociatedException ¶
type ResourceAssociatedException struct {
Message *string
}
The resource is associated with a directory.
func (*ResourceAssociatedException) Error ¶
func (e *ResourceAssociatedException) Error() string
func (*ResourceAssociatedException) ErrorCode ¶
func (e *ResourceAssociatedException) ErrorCode() string
func (*ResourceAssociatedException) ErrorFault ¶
func (e *ResourceAssociatedException) ErrorFault() smithy.ErrorFault
func (*ResourceAssociatedException) ErrorMessage ¶
func (e *ResourceAssociatedException) ErrorMessage() string
func (*ResourceAssociatedException) GetMessage ¶
func (e *ResourceAssociatedException) GetMessage() string
func (*ResourceAssociatedException) HasMessage ¶
func (e *ResourceAssociatedException) HasMessage() bool
type ResourceCreationFailedException ¶
type ResourceCreationFailedException struct {
Message *string
}
The resource could not be created.
func (*ResourceCreationFailedException) Error ¶
func (e *ResourceCreationFailedException) Error() string
func (*ResourceCreationFailedException) ErrorCode ¶
func (e *ResourceCreationFailedException) ErrorCode() string
func (*ResourceCreationFailedException) ErrorFault ¶
func (e *ResourceCreationFailedException) ErrorFault() smithy.ErrorFault
func (*ResourceCreationFailedException) ErrorMessage ¶
func (e *ResourceCreationFailedException) ErrorMessage() string
func (*ResourceCreationFailedException) GetMessage ¶
func (e *ResourceCreationFailedException) GetMessage() string
func (*ResourceCreationFailedException) HasMessage ¶
func (e *ResourceCreationFailedException) HasMessage() bool
type ResourceLimitExceededException ¶
type ResourceLimitExceededException struct {
Message *string
}
Your resource limits have been exceeded.
func (*ResourceLimitExceededException) Error ¶
func (e *ResourceLimitExceededException) Error() string
func (*ResourceLimitExceededException) ErrorCode ¶
func (e *ResourceLimitExceededException) ErrorCode() string
func (*ResourceLimitExceededException) ErrorFault ¶
func (e *ResourceLimitExceededException) ErrorFault() smithy.ErrorFault
func (*ResourceLimitExceededException) ErrorMessage ¶
func (e *ResourceLimitExceededException) ErrorMessage() string
func (*ResourceLimitExceededException) GetMessage ¶
func (e *ResourceLimitExceededException) GetMessage() string
func (*ResourceLimitExceededException) HasMessage ¶
func (e *ResourceLimitExceededException) HasMessage() bool
type ResourceNotFoundException ¶
The resource could not be found.
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
func (*ResourceNotFoundException) GetMessage ¶
func (e *ResourceNotFoundException) GetMessage() string
func (*ResourceNotFoundException) GetResourceId ¶
func (e *ResourceNotFoundException) GetResourceId() string
func (*ResourceNotFoundException) HasMessage ¶
func (e *ResourceNotFoundException) HasMessage() bool
func (*ResourceNotFoundException) HasResourceId ¶
func (e *ResourceNotFoundException) HasResourceId() bool
type ResourceUnavailableException ¶
type ResourceUnavailableException struct {
}
The specified resource is not available.
func (*ResourceUnavailableException) Error ¶
func (e *ResourceUnavailableException) Error() string
func (*ResourceUnavailableException) ErrorCode ¶
func (e *ResourceUnavailableException) ErrorCode() string
func (*ResourceUnavailableException) ErrorFault ¶
func (e *ResourceUnavailableException) ErrorFault() smithy.ErrorFault
func (*ResourceUnavailableException) ErrorMessage ¶
func (e *ResourceUnavailableException) ErrorMessage() string
func (*ResourceUnavailableException) GetMessage ¶
func (e *ResourceUnavailableException) GetMessage() string
func (*ResourceUnavailableException) GetResourceId ¶
func (e *ResourceUnavailableException) GetResourceId() string
func (*ResourceUnavailableException) HasMessage ¶
func (e *ResourceUnavailableException) HasMessage() bool
func (*ResourceUnavailableException) HasResourceId ¶
func (e *ResourceUnavailableException) HasResourceId() bool
type RootStorage ¶
type RootStorage struct {
// The size of the root volume.
Capacity *string
}
Describes the root volume for a WorkSpace bundle.
type RunningMode ¶
type RunningMode string
const ( RunningModeAuto_stop RunningMode = "AUTO_STOP" RunningModeAlways_on RunningMode = "ALWAYS_ON" )
Enum values for RunningMode
type SelfservicePermissions ¶
type SelfservicePermissions struct {
// Specifies whether users can switch the running mode of their WorkSpace.
SwitchRunningMode ReconnectEnum
// Specifies whether users can rebuild the operating system of a WorkSpace to its
// original state.
RebuildWorkspace ReconnectEnum
// Specifies whether users can change the compute type (bundle) for their
// WorkSpace.
ChangeComputeType ReconnectEnum
// Specifies whether users can restart their WorkSpace.
RestartWorkspace ReconnectEnum
// Specifies whether users can increase the volume size of the drives on their
// WorkSpace.
IncreaseVolumeSize ReconnectEnum
}
Describes the self-service permissions for a directory. For more information, see Enable Self-Service WorkSpace Management Capabilities for Your Users (https://docs.aws.amazon.com/workspaces/latest/adminguide/enable-user-self-service-workspace-management.html).
type StartRequest ¶
type StartRequest struct {
// The identifier of the WorkSpace.
WorkspaceId *string
}
Information used to start a WorkSpace.
type StopRequest ¶
type StopRequest struct {
// The identifier of the WorkSpace.
WorkspaceId *string
}
Describes the information used to stop a WorkSpace.
type TargetWorkspaceState ¶
type TargetWorkspaceState string
const ( TargetWorkspaceStateAvailable TargetWorkspaceState = "AVAILABLE" TargetWorkspaceStateAdmin_maintenance TargetWorkspaceState = "ADMIN_MAINTENANCE" )
Enum values for TargetWorkspaceState
type Tenancy ¶
type Tenancy string
const ( TenancyDedicated Tenancy = "DEDICATED" )
Enum values for Tenancy
type TerminateRequest ¶
type TerminateRequest struct {
// The identifier of the WorkSpace.
WorkspaceId *string
}
Describes the information used to terminate a WorkSpace.
type UnsupportedNetworkConfigurationException ¶
type UnsupportedNetworkConfigurationException struct {
Message *string
}
The configuration of this network is not supported for this operation, or your network configuration conflicts with the Amazon WorkSpaces management network IP range. For more information, see Configure a VPC for Amazon WorkSpaces (https://docs.aws.amazon.com/workspaces/latest/adminguide/amazon-workspaces-vpc.html).
func (*UnsupportedNetworkConfigurationException) Error ¶
func (e *UnsupportedNetworkConfigurationException) Error() string
func (*UnsupportedNetworkConfigurationException) ErrorCode ¶
func (e *UnsupportedNetworkConfigurationException) ErrorCode() string
func (*UnsupportedNetworkConfigurationException) ErrorFault ¶
func (e *UnsupportedNetworkConfigurationException) ErrorFault() smithy.ErrorFault
func (*UnsupportedNetworkConfigurationException) ErrorMessage ¶
func (e *UnsupportedNetworkConfigurationException) ErrorMessage() string
func (*UnsupportedNetworkConfigurationException) GetMessage ¶
func (e *UnsupportedNetworkConfigurationException) GetMessage() string
func (*UnsupportedNetworkConfigurationException) HasMessage ¶
func (e *UnsupportedNetworkConfigurationException) HasMessage() bool
type UnsupportedWorkspaceConfigurationException ¶
type UnsupportedWorkspaceConfigurationException struct {
Message *string
}
The configuration of this WorkSpace is not supported for this operation. For more information, see Required Configuration and Service Components for WorkSpaces (https://docs.aws.amazon.com/workspaces/latest/adminguide/required-service-components.html).
func (*UnsupportedWorkspaceConfigurationException) Error ¶
func (e *UnsupportedWorkspaceConfigurationException) Error() string
func (*UnsupportedWorkspaceConfigurationException) ErrorCode ¶
func (e *UnsupportedWorkspaceConfigurationException) ErrorCode() string
func (*UnsupportedWorkspaceConfigurationException) ErrorFault ¶
func (e *UnsupportedWorkspaceConfigurationException) ErrorFault() smithy.ErrorFault
func (*UnsupportedWorkspaceConfigurationException) ErrorMessage ¶
func (e *UnsupportedWorkspaceConfigurationException) ErrorMessage() string
func (*UnsupportedWorkspaceConfigurationException) GetMessage ¶
func (e *UnsupportedWorkspaceConfigurationException) GetMessage() string
func (*UnsupportedWorkspaceConfigurationException) HasMessage ¶
func (e *UnsupportedWorkspaceConfigurationException) HasMessage() bool
type UserStorage ¶
type UserStorage struct {
// The size of the user storage.
Capacity *string
}
Describes the user storage for a WorkSpace bundle.
type Workspace ¶
type Workspace struct {
// The user for the WorkSpace.
UserName *string
// The identifier of the subnet for the WorkSpace.
SubnetId *string
// The error code that is returned if the WorkSpace cannot be created.
ErrorCode *string
// Indicates whether the data stored on the user volume is encrypted.
UserVolumeEncryptionEnabled *bool
// The modification states of the WorkSpace.
ModificationStates []*ModificationState
// The symmetric AWS KMS customer master key (CMK) used to encrypt data stored on
// your WorkSpace. Amazon WorkSpaces does not support asymmetric CMKs.
VolumeEncryptionKey *string
// The operational state of the WorkSpace.
State WorkspaceState
// The properties of the WorkSpace.
WorkspaceProperties *WorkspaceProperties
// The IP address of the WorkSpace.
IpAddress *string
// Indicates whether the data stored on the root volume is encrypted.
RootVolumeEncryptionEnabled *bool
// The text of the error message that is returned if the WorkSpace cannot be
// created.
ErrorMessage *string
// The identifier of the bundle used to create the WorkSpace.
BundleId *string
// The identifier of the AWS Directory Service directory for the WorkSpace.
DirectoryId *string
// The identifier of the WorkSpace.
WorkspaceId *string
// The name of the WorkSpace, as seen by the operating system.
ComputerName *string
}
Describes a WorkSpace.
type WorkspaceAccessProperties ¶
type WorkspaceAccessProperties struct {
// Indicates whether users can use zero client devices to access their WorkSpaces.
DeviceTypeZeroClient AccessPropertyValue
// Indicates whether users can use iOS devices to access their WorkSpaces.
DeviceTypeIos AccessPropertyValue
// Indicates whether users can use Android devices to access their WorkSpaces.
DeviceTypeAndroid AccessPropertyValue
// Indicates whether users can use Chromebooks to access their WorkSpaces.
DeviceTypeChromeOs AccessPropertyValue
// Indicates whether users can access their WorkSpaces through a web browser.
DeviceTypeWeb AccessPropertyValue
// Indicates whether users can use macOS clients to access their WorkSpaces. To
// restrict WorkSpaces access to trusted devices (also known as managed devices)
// with valid certificates, specify a value of TRUST. For more information, see
// Restrict WorkSpaces Access to Trusted Devices
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/trusted-devices.html).
DeviceTypeOsx AccessPropertyValue
// Indicates whether users can use Windows clients to access their WorkSpaces. To
// restrict WorkSpaces access to trusted devices (also known as managed devices)
// with valid certificates, specify a value of TRUST. For more information, see
// Restrict WorkSpaces Access to Trusted Devices
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/trusted-devices.html).
DeviceTypeWindows AccessPropertyValue
}
The device types and operating systems that can be used to access a WorkSpace. For more information, see Amazon WorkSpaces Client Network Requirements (https://docs.aws.amazon.com/workspaces/latest/adminguide/workspaces-network-requirements.html).
type WorkspaceBundle ¶
type WorkspaceBundle struct {
// The image identifier of the bundle.
ImageId *string
// The owner of the bundle. This is the account identifier of the owner, or AMAZON
// if the bundle is provided by AWS.
Owner *string
// A description.
Description *string
// The compute type. For more information, see Amazon WorkSpaces Bundles
// (http://aws.amazon.com/workspaces/details/#Amazon_WorkSpaces_Bundles).
ComputeType *ComputeType
// The size of the user storage.
UserStorage *UserStorage
// The bundle identifier.
BundleId *string
// The last time that the bundle was updated.
LastUpdatedTime *time.Time
// The name of the bundle.
Name *string
// The size of the root volume.
RootStorage *RootStorage
}
Describes a WorkSpace bundle.
type WorkspaceConnectionStatus ¶
type WorkspaceConnectionStatus struct {
// The identifier of the WorkSpace.
WorkspaceId *string
// The connection state of the WorkSpace. The connection state is unknown if the
// WorkSpace is stopped.
ConnectionState ConnectionState
// The timestamp of the last known user connection.
LastKnownUserConnectionTimestamp *time.Time
// The timestamp of the connection status check.
ConnectionStateCheckTimestamp *time.Time
}
Describes the connection status of a WorkSpace.
type WorkspaceCreationProperties ¶
type WorkspaceCreationProperties struct {
// The identifier of your custom security group.
CustomSecurityGroupId *string
// Indicates whether internet access is enabled for your WorkSpaces.
EnableInternetAccess *bool
// Indicates whether maintenance mode is enabled for your WorkSpaces. For more
// information, see WorkSpace Maintenance
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/workspace-maintenance.html).
EnableMaintenanceMode *bool
// Indicates whether users are local administrators of their WorkSpaces.
UserEnabledAsLocalAdministrator *bool
// The default organizational unit (OU) for your WorkSpace directories.
DefaultOu *string
}
Describes the default properties that are used for creating WorkSpaces. For more information, see Update Directory Details for Your WorkSpaces (https://docs.aws.amazon.com/workspaces/latest/adminguide/update-directory-details.html).
type WorkspaceDirectory ¶
type WorkspaceDirectory struct {
// The name of the directory.
DirectoryName *string
// The user name for the service account.
CustomerUserName *string
// The identifier of the IAM role. This is the role that allows Amazon WorkSpaces
// to make calls to other services, such as Amazon EC2, on your behalf.
IamRoleId *string
// Specifies whether the directory is dedicated or shared. To use Bring Your Own
// License (BYOL), this value must be set to DEDICATED. For more information, see
// Bring Your Own Windows Desktop Images
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/byol-windows-images.html).
Tenancy Tenancy
// The directory identifier.
DirectoryId *string
// The devices and operating systems that users can use to access WorkSpaces.
WorkspaceAccessProperties *WorkspaceAccessProperties
// The default self-service permissions for WorkSpaces in the directory.
SelfservicePermissions *SelfservicePermissions
// The registration code for the directory. This is the code that users enter in
// their Amazon WorkSpaces client application to connect to the directory.
RegistrationCode *string
// The IP addresses of the DNS servers for the directory.
DnsIpAddresses []*string
// The identifier of the security group that is assigned to new WorkSpaces.
WorkspaceSecurityGroupId *string
// The directory type.
DirectoryType WorkspaceDirectoryType
// The default creation properties for all WorkSpaces in the directory.
WorkspaceCreationProperties *DefaultWorkspaceCreationProperties
// The state of the directory's registration with Amazon WorkSpaces.
State WorkspaceDirectoryState
// The identifiers of the IP access control groups associated with the directory.
IpGroupIds []*string
// The directory alias.
Alias *string
// The identifiers of the subnets used with the directory.
SubnetIds []*string
}
Describes a directory that is used with Amazon WorkSpaces.
type WorkspaceDirectoryState ¶
type WorkspaceDirectoryState string
const ( WorkspaceDirectoryStateRegistering WorkspaceDirectoryState = "REGISTERING" WorkspaceDirectoryStateRegistered WorkspaceDirectoryState = "REGISTERED" WorkspaceDirectoryStateDeregistering WorkspaceDirectoryState = "DEREGISTERING" WorkspaceDirectoryStateDeregistered WorkspaceDirectoryState = "DEREGISTERED" WorkspaceDirectoryStateError WorkspaceDirectoryState = "ERROR" )
Enum values for WorkspaceDirectoryState
type WorkspaceDirectoryType ¶
type WorkspaceDirectoryType string
const ( WorkspaceDirectoryTypeSimple_ad WorkspaceDirectoryType = "SIMPLE_AD" WorkspaceDirectoryTypeAd_connector WorkspaceDirectoryType = "AD_CONNECTOR" )
Enum values for WorkspaceDirectoryType
type WorkspaceImage ¶
type WorkspaceImage struct {
// The name of the image.
Name *string
// The error code that is returned for the image.
ErrorCode *string
// The identifier of the image.
ImageId *string
// Specifies whether the image is running on dedicated hardware. When Bring Your
// Own License (BYOL) is enabled, this value is set to DEDICATED. For more
// information, see Bring Your Own Windows Desktop Images
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/byol-windows-images.html).
RequiredTenancy WorkspaceImageRequiredTenancy
// The status of the image.
State WorkspaceImageState
// The description of the image.
Description *string
// The identifier of the AWS account that owns the image.
OwnerAccountId *string
// The operating system that the image is running.
OperatingSystem *OperatingSystem
// The date when the image was created. If the image has been shared, the AWS
// account that the image has been shared with sees the original creation date of
// the image.
Created *time.Time
// The text of the error message that is returned for the image.
ErrorMessage *string
}
Describes a WorkSpace image.
type WorkspaceImageIngestionProcess ¶
type WorkspaceImageIngestionProcess string
const ( WorkspaceImageIngestionProcessByol_regular WorkspaceImageIngestionProcess = "BYOL_REGULAR" WorkspaceImageIngestionProcessByol_graphics WorkspaceImageIngestionProcess = "BYOL_GRAPHICS" WorkspaceImageIngestionProcessByol_graphicspro WorkspaceImageIngestionProcess = "BYOL_GRAPHICSPRO" )
Enum values for WorkspaceImageIngestionProcess
type WorkspaceImageRequiredTenancy ¶
type WorkspaceImageRequiredTenancy string
const ( WorkspaceImageRequiredTenancyDefault WorkspaceImageRequiredTenancy = "DEFAULT" WorkspaceImageRequiredTenancyDedicated WorkspaceImageRequiredTenancy = "DEDICATED" )
Enum values for WorkspaceImageRequiredTenancy
type WorkspaceImageState ¶
type WorkspaceImageState string
const ( WorkspaceImageStateAvailable WorkspaceImageState = "AVAILABLE" WorkspaceImageStatePending WorkspaceImageState = "PENDING" WorkspaceImageStateError WorkspaceImageState = "ERROR" )
Enum values for WorkspaceImageState
type WorkspaceProperties ¶
type WorkspaceProperties struct {
// The time after a user logs off when WorkSpaces are automatically stopped.
// Configured in 60-minute intervals.
RunningModeAutoStopTimeoutInMinutes *int32
// The size of the user storage. For important information about how to modify the
// size of the root and user volumes, see Modify a WorkSpace
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/modify-workspaces.html).
UserVolumeSizeGib *int32
// The size of the root volume. For important information about how to modify the
// size of the root and user volumes, see Modify a WorkSpace
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/modify-workspaces.html).
RootVolumeSizeGib *int32
// The compute type. For more information, see Amazon WorkSpaces Bundles
// (http://aws.amazon.com/workspaces/details/#Amazon_WorkSpaces_Bundles).
ComputeTypeName Compute
// The running mode. For more information, see Manage the WorkSpace Running Mode
// (https://docs.aws.amazon.com/workspaces/latest/adminguide/running-mode.html).
RunningMode RunningMode
}
Describes a WorkSpace.
type WorkspaceRequest ¶
type WorkspaceRequest struct {
// The symmetric AWS KMS customer master key (CMK) used to encrypt data stored on
// your WorkSpace. Amazon WorkSpaces does not support asymmetric CMKs.
VolumeEncryptionKey *string
// Indicates whether the data stored on the root volume is encrypted.
RootVolumeEncryptionEnabled *bool
// The user name of the user for the WorkSpace. This user name must exist in the
// AWS Directory Service directory for the WorkSpace.
UserName *string
// The identifier of the bundle for the WorkSpace. You can use
// DescribeWorkspaceBundles () to list the available bundles.
BundleId *string
// The tags for the WorkSpace.
Tags []*Tag
// The WorkSpace properties.
WorkspaceProperties *WorkspaceProperties
// Indicates whether the data stored on the user volume is encrypted.
UserVolumeEncryptionEnabled *bool
// The identifier of the AWS Directory Service directory for the WorkSpace. You can
// use DescribeWorkspaceDirectories () to list the available directories.
DirectoryId *string
}
Describes the information used to create a WorkSpace.
type WorkspaceState ¶
type WorkspaceState string
const ( WorkspaceStatePending WorkspaceState = "PENDING" WorkspaceStateAvailable WorkspaceState = "AVAILABLE" WorkspaceStateImpaired WorkspaceState = "IMPAIRED" WorkspaceStateUnhealthy WorkspaceState = "UNHEALTHY" WorkspaceStateRebooting WorkspaceState = "REBOOTING" WorkspaceStateStarting WorkspaceState = "STARTING" WorkspaceStateRebuilding WorkspaceState = "REBUILDING" WorkspaceStateRestoring WorkspaceState = "RESTORING" WorkspaceStateMaintenance WorkspaceState = "MAINTENANCE" WorkspaceStateAdmin_maintenance WorkspaceState = "ADMIN_MAINTENANCE" WorkspaceStateTerminating WorkspaceState = "TERMINATING" WorkspaceStateTerminated WorkspaceState = "TERMINATED" WorkspaceStateSuspended WorkspaceState = "SUSPENDED" WorkspaceStateUpdating WorkspaceState = "UPDATING" WorkspaceStateStopping WorkspaceState = "STOPPING" WorkspaceStateStopped WorkspaceState = "STOPPED" WorkspaceStateError WorkspaceState = "ERROR" )
Enum values for WorkspaceState
type WorkspacesDefaultRoleNotFoundException ¶
type WorkspacesDefaultRoleNotFoundException struct {
Message *string
}
The workspaces_DefaultRole role could not be found. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see Creating the workspaces_DefaultRole Role (https://docs.aws.amazon.com/workspaces/latest/adminguide/workspaces-access-control.html#create-default-role).
func (*WorkspacesDefaultRoleNotFoundException) Error ¶
func (e *WorkspacesDefaultRoleNotFoundException) Error() string
func (*WorkspacesDefaultRoleNotFoundException) ErrorCode ¶
func (e *WorkspacesDefaultRoleNotFoundException) ErrorCode() string
func (*WorkspacesDefaultRoleNotFoundException) ErrorFault ¶
func (e *WorkspacesDefaultRoleNotFoundException) ErrorFault() smithy.ErrorFault
func (*WorkspacesDefaultRoleNotFoundException) ErrorMessage ¶
func (e *WorkspacesDefaultRoleNotFoundException) ErrorMessage() string
func (*WorkspacesDefaultRoleNotFoundException) GetMessage ¶
func (e *WorkspacesDefaultRoleNotFoundException) GetMessage() string
func (*WorkspacesDefaultRoleNotFoundException) HasMessage ¶
func (e *WorkspacesDefaultRoleNotFoundException) HasMessage() bool
type WorkspacesIpGroup ¶
type WorkspacesIpGroup struct {
// The identifier of the group.
GroupId *string
// The rules.
UserRules []*IpRuleItem
// The name of the group.
GroupName *string
// The description of the group.
GroupDesc *string
}
Describes an IP access control group.